@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2019  Winfried Bruns, Bogdan Ichim, Christof Soeger
+ * Copyright (C) 2007-2021  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -64,7 +64,6 @@ namespace ConeProperty {
 enum Enum {
     // matrix valued
     START_ENUM_RANGE(FIRST_MATRIX),
-    Generators,
     ExtremeRays,
     VerticesOfPolyhedron,
     SupportHyperplanes,
@@ -81,6 +80,7 @@ enum Enum {
     END_ENUM_RANGE(LAST_MATRIX),
 
     START_ENUM_RANGE(FIRST_MATRIX_FLOAT),
+    ExtremeRaysFloat,
     SuppHypsFloat,
     VerticesFloat,
     END_ENUM_RANGE(LAST_MATRIX_FLOAT),
@@ -228,12 +228,16 @@ enum Enum {
     //
     Dynamic,
     Static,
+    END_ENUM_RANGE(LAST_PROPERTY),
     //
     // ONLY FOR INTERNAL CONTROL
     //
-    // ExplicitHilbertSeries,
+    START_ENUM_RANGE(FIRST_INTERNAL),
+    BasicTriangulation,
+    BasicStanleyDec,
     NakedDual,
     FullConeDynamic,
+    Generators,
     //
     // ONLY FOR E§XTENDED TESTS
     //
@@ -246,7 +250,7 @@ enum Enum {
     TestLinearAlgebraGMP,
     TestSimplexParallel,
     TestLibNormaliz,
-    END_ENUM_RANGE(LAST_PROPERTY),
+    END_ENUM_RANGE(LAST_INTERNAL),
 
     EnumSize  // this has to be the last entry, to get the number of entries in the enum
 
